==> kotlin-compiler-embeddable-0.13.1516-sources.jar: org/jetbrains/kotlin/load/java/descriptors/SamConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.load.java.descriptors

import org.jetbrains.kotlin.descriptors.impl.SimpleFunctionDescriptorImpl
import org.jetbrains.kotlin.descriptors.CallableMemberDescriptor
import org.jetbrains.kotlin.descriptors.DeclarationDescriptor
import org.jetbrains.kotlin.resolve.scopes.DescriptorKindExclude

public class SamConstructorDescriptor(
        containingDeclaration: DeclarationDescriptor,
        samInterface: JavaClassDescriptor
) : SimpleFunctionDescriptorImpl(
        containingDeclaration,
        null,
        samInterface.getAnnotations(),
        samInterface.getName(),
        CallableMemberDescriptor.Kind.SYNTHESIZED,
        samInterface.getSource()
)

public object SamConstructorDescriptorKindExclude : DescriptorKindExclude {
    override fun excludes(descriptor: DeclarationDescriptor) = descriptor is SamConstructorDescriptor

    override val fullyExcludedDescriptorKinds: Int get() = 0
}

==> kotlin-compiler-embeddable-1.0.1-2-sources.jar: org/jetbrains/kotlin/load/java/descriptors/SamConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.load.java.descriptors

import org.jetbrains.kotlin.descriptors.impl.SimpleFunctionDescriptorImpl
import org.jetbrains.kotlin.descriptors.CallableMemberDescriptor
import org.jetbrains.kotlin.descriptors.DeclarationDescriptor
import org.jetbrains.kotlin.resolve.scopes.DescriptorKindExclude

class SamConstructorDescriptor(
        containingDeclaration: DeclarationDescriptor,
        samInterface: JavaClassDescriptor
) : SimpleFunctionDescriptorImpl(
        containingDeclaration,
        null,
        samInterface.annotations,
        samInterface.name,
        CallableMemberDescriptor.Kind.SYNTHESIZED,
        samInterface.source
)

object SamConstructorDescriptorKindExclude : DescriptorKindExclude() {
    override fun excludes(descriptor: DeclarationDescriptor) = descriptor is SamConstructorDescriptor

    override val fullyExcludedDescriptorKinds: Int get() = 0
}
